# Libpythonpro
Projeto que visa mexer com o virtualenv

Nesse projeto é apresentado como contribuir com projetos de código aberto

Suportada a versão 3 do Python
[![Python 3](https://pyup.io/repos/github/Gh-Cunha/libpythonpro-1/python-3-shield.svg)](https://pyup.io/repos/github/Gh-Cunha/libpythonpro-1/)
[![Updates](https://pyup.io/repos/github/Gh-Cunha/libpythonpro-1/shield.svg)](https://pyup.io/repos/github/Gh-Cunha/libpythonpro-1/)

Para instalar:

'''console
py -m venv .venv
source .venv/Scripts/activate
pip install -r requirements-dev.txt
'''


Para conferir qualidade de código:
'''console
flake8

'''

Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. pip